@@ -43,9 +43,12 @@ logger = logging.getLogger(__name__)
 
 class VaspToDbTaskDrone(AbstractDrone):
     """
-    VaspToDbDictDrone assimilates directories containing vasp input to
-    inserted db tasks. This drone is meant ot be used withg pymatgen's
-    BorgQueen to assimilate
+    VaspToDbTaskDrone assimilates directories containing vasp input to
+    inserted db tasks. This drone is meant ot be used with pymatgen's
+    BorgQueen to assimilate entire directory structures and insert them into
+    a database using Python's multiprocessing. The current format assumes
+    standard VASP relaxation runs. If you have other kinds of runs,
+    you may design your own VaspDbTaskDrone based on this one.
 
     There are some restrictions on the valid directory structures:
 
